@@ -12,7 +12,7 @@ from urllib.parse import quote
 from uuid import uuid1
 from sqlalchemy import MetaData, Table
 from sqlalchemy.orm import scoped_session, sessionmaker
-from datetime import datetime, date, time
+from datetime import datetime, date, time, timedelta
 
 
 # some constants
@@ -185,6 +185,7 @@ class SecureFlaskApp(Flask):
         self.secret_key = str(uuid1())
         self.config["SECRET_KEY"] = self.secret_key
         self.config["TEMPLATES_AUTO_RELOAD"] = True
+        self.config['PERMANENT_SESSION_LIFETIME'] =  timedelta(days=1)
         self.jinja_env.auto_reload = True
 
         # set any user-provided configs
